******************************************************************************
*                                                                            *
*   PROGRAM: array                                                           *
*                                                                            *
*   PURPOSE: Create Awas geometry input data for an array of identical       *
*            structures                                                      *
*                                                                            *
******************************************************************************

	program array

c	the basic structure is read from a geometry file
c	the array elements can be placed, rotated, and excited arbitrarily

	dimension x(999),y(999),z(999),join1(999),join2(999),a(999),
     1	ild(3,999),parld(10,999),igenb(99),igent(99),zcgen(99)
	complex excit(99)
	dimension xa(999),ya(999),za(999),rot(3,3,999),coordo(3),
     1	coordn(3)
	complex excita(99)

	character*80 title
	character*20 filein

c	the data for the array are located in the file array.dat

	open (file='array.dat',unit=1,status='old')

c	read the geometry file name of the basic structure

	read(1,'(a20)')filein

c	open the file that defines the basic structure and read it

	open (file=filein,unit=2,status='old')

	read(2,'(a80)')title
	read(2,'(a80)')title
	read(2,'(a80)')title
	read(2,*)mode
	read(2,*)ignd
	read(2,*)nn
	if(nn.gt.999) go to 990
	read(2,*)nb
	if(nb.gt.999) go to 990
	read(2,*)ng
	if(ng.gt.99) go to 990

	do i=1,nn
	  read(2,*)x(i),y(i),z(i)
	end do

	do i=1,nb
	  read(2,*)join1(i),join2(i),a(i),(ild(j,i),j=1,3),
     1	  (parld(j,i),j=1,10)
	end do

	do i=1,ng
	  read(2,*)igenb(i),igent(i),excit(i),zcgen(i)
	end do

	close (2)

c	read the number of elements in the array

	read(1,*)ne
	if(ne.gt.99) go to 990

c	open the geometry data file for the array

	open (file='array.geo',unit=2)

	write(2,200)
	write(2,200)
	write(2,200)
200	format('                                     ',
     1	'                                       ')

	write(2,*)mode
	write(2,*)ignd

	write(2,*)nn*ne
	write(2,*)nb*ne
	write(2,*)ng*ne

	write(2,*)

	do i=1,ne

c	read the translated coordinate origin for each array element

	  read(1,*)xa(i),ya(i),za(i)

c	read the rotation matrix for each array element

	  read(1,*)((rot(j,k,i),k=1,3),j=1,3)

c	read the relative excitation for each array element

	  read(1,*)excita(i)
	end do

	close (1)

c	calculate and write node coordinates for array elements

	do i=1,ne
	  do j=1,nn
	    coordo(1)=x(j)
	    coordo(2)=y(j)
	    coordo(3)=z(j)
	    call mprd(rot(1,1,i),coordo,coordn,3,3,1,3,3,1)
	    write(2,*)coordn(1)+xa(i),coordn(2)+ya(i),coordn(3)+za(i)
	  end do
	end do

	write(2,*)

c	write data for segments

	do i=1,ne
	  do j=1,nb
	    write(2,*)join1(j)+(i-1)*nn,join2(j)+(i-1)*nn,a(j),
     1	    (ild(k,j),k=1,3),(parld(k,j),k=1,10)
	  end do
	end do

c	write data for ports

	do i=1,ne
	  do j=1,ng
	    write(2,*)igenb(j)+(i-1)*nb,igent(j),excit(j)*excita(i),
     1	    zcgen(j)
	  end do
	end do

	close(2)

	go to 999
990	write(*,*)'Error in input data'

999	end



*******************
*                 *
* SUBROUTINE MPRD *
*                 *
*******************

	SUBROUTINE MPRD(A,B,C,L,M,N,NA,NB,NC)

C	COMPUTE PRODUCT OF TWO REAL MATRICES
C	A - FIRST MATRIX, OF DIMENSION L*M
C	B - SECOND MATRIX, OF DIMENSION M*N
C	C - OUTPUT MATRIX, C=A*B, OF DIMENSION L*N
C	NA,NB,NC - ACTUAL ROW DIMENSIONS OF MATRICES A,B,C,
C	AS SPECIFIED IN THE DIMENSION STATEMENT IN THE CALLING PROGRAM


	REAL A(NA,*),B(NB,*),C(NC,*),T

	DO I=1,L
	  DO J=1,N
	    T=0.
	    DO K=1,M
	      T=A(I,K)*B(K,J)+T
	    END DO
	    C(I,J)=T
	  END DO
	END DO

	RETURN
	END