******************************************************************************
*                                                                            *
*   PROGRAM: block                                                           *
*                                                                            *
*   PURPOSE: Create Awas geometry input data file for a dielectric block     *
*                                                                            *
******************************************************************************

	program block

c	the block is simulated by a spatial wire grid with capacitively
c	loaded wires (artificial dielectric)
c	the block is placed on a ground plane

	implicit none
	real a,b,h,r,x,y,z,dx,dy,dz,epsr,eps,cx,cy,cz,czt
	integer na,nb,nh,nn,ns,i,j,k,nodea,nodeb

c	get input data from the default input device (keyboard)
c	numbers are entered in a free format

c	a - block length (along x-axis)
c	b - block width (along y-axis)
c	h - block height (along z-axis)
c	these dimensions are input in millimeters

	print 101
101	format(' Dimensions a,b,h (mm)? ',$)
	read(*,*)a,b,h

c	convert dimensions to meters

	a=0.001*a
	b=0.001*b
	h=0.001*h

c	na - number of eyelets along a
c	nb - number of eyelets along b
c	nh - number of eyelets along h

	print 102
102	format(' Numbers of eyelets per a,b,h? ',$)
	read(*,*)na,nb,nh

c	epsr - relative permittivity of the dielectric

	print 103
103	format(' Relative permittivity? ',$)
	read(*,*)epsr

	dx=a/(na+1)
	dy=b/(nb+1)
	dz=h/(nh+1)

c	automatically define wire radius

	r=0.1*dx
	if(r.gt.0.1*dy) r=0.1*dy
	if(r.gt.0.1*dz) r=0.1*dz

c	end of input

* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *

c	open file block.geo

	open (unit=1,file='block.geo')

c	write title

	write(1,201)' '
	write(1,201)' '
	write(1,201)' '
201	format(a76)

c	write operating mode code (scatterer, bistatic scattering)

	write(1,*)-3

c	write ground plane code (ground plane present)

	write(1,*)1

c	calculate numbers of nodes and segments
c	nn - number of nodes
c	ns - number of segments

	nn=(na+1)*(nb+1)*(nh+2)
	ns=na*(nb+1)*(nh+1)+(na+1)*nb*(nh+1)+(na+1)*(nb+1)*(nh+1)


c	write number of nodes

	write(1,*)nn

c	write number of segments

	write(1,*)ns

c	write number of ports (no ports, the structure is a scatterer)

	write(1,*)0

c	write a blank line (optional)

	write(1,*)

c	define nodes

	do k=-1,nh
	  if(k.eq.-1) then
	    z=0.
	  else
	    z=(k+0.5)*dz
	  end if
	  do j=0,nb
	    y=-0.5*b+(j+0.5)*dy
	    do i=0,na

c	write node coordinates (x,y,z)

	      x=-0.5*a+(i+0.5)*dx
	      write(1,*)x,y,z
	    end do
	  end do
	end do

c	write a blank line (optional)

	write(1,*)

c	calculate loading capacitances (from parallel-plate approximation)

	eps=8.8542e-12*epsr
	cx=eps*dy*dz/dx
	cy=eps*dx*dz/dy
	cz=eps*dx*dy/dz

c	define segments parallel to x-axis

	nodea=0
	do k=-1,nh
	  do j=0,nb
	    do i=0,na
	      nodea=nodea+1
	      nodeb=nodea+1

c	write segment data
c	nodea - origin node
c	nodeb - terminal node
c	r - wire radius
c	the lumped impedances are 0 and the capacitance is distributed

	      if(k.ge.0.and.i.lt.na) write(1,*)
     1	nodea,nodeb,r,' 0 0 4 0. 0. 0. 0. 0. 0. 0. 0. ',cx,' 0.'
	    end do
	  end do
	end do

c	define segments parallel to y-axis

	nodea=0
	do k=-1,nh
	  do j=0,nb
	    do i=0,na
	      nodea=nodea+1
	      nodeb=nodea+na+1

c	write segment data

	      if(k.ge.0.and.j.lt.nb) write(1,*)
     1	nodea,nodeb,r,' 0 0 4 0. 0. 0. 0. 0. 0. 0. 0. ',cy,' 0.'
	    end do
	  end do
	end do

c	define segments parallel to z-axis

	nodea=0
	do k=-1,nh
	  do j=0,nb
	    do i=0,na
	      nodea=nodea+1
	      nodeb=nodea+(na+1)*(nb+1)
	      if(k.eq.0) then
	        czt=cz/2.
	      else
	        czt=cz
	      end if

c	write segment data

	      if(k.lt.nh) write(1,*)
     1	nodea,nodeb,r,' 0 0 4 0. 0. 0. 0. 0. 0. 0. 0. ',czt,' 0.'
	    end do
	  end do
	end do

	end