******************************************************************************
*                                                                            *
*   PROGRAM: helix                                                           *
*                                                                            *
*   PURPOSE: Create Awas geometry input data file for a helix antenna        *
*                                                                            *
******************************************************************************

	program helix

c	The antenna is located above a ground plane and fed at that plane

c	The basic data are input from the keyboard,
c	and the data created by the program are written in the file HELIX.GEO

c	ENTER DATA

c	Enter number of turns (integer)

	write(*,100)
100	format(' Number of turns? ',$)
	read(*,*)n
	if(n.lt.1) n=1

c	Enter number of segments per turn (integer)

	write(*,101)
101	format(' Number of segments per turn? ',$)
	read(*,*)m
	if(m.lt.3) n=3

c	Enter helih radius, pitch and wire radius

	write(*,102)
102	format(' Helix radius (m)? ',$)
	read(*,*)hr
	write(*,103)
103	format(' Helix pitch (m)? ',$)
	read(*,*)hp
	write(*,104)
104	format(' Wire radius (m)? ',$)
	read(*,*)wr

c	Open file HELIX.GEO (the old copy will be deleted if it exists)

	open (file='helix.geo',unit=1)

c	Write three title lines

	write(1,200)
	write(1,200)
	write(1,200)
200	format('                                     ',
     1	'                                       ')

c	Write operating mode code (transmitting antenna, all ports)

	write(1,*)1

c	Write ground plane indicator (ground plane present)

	write(1,*)1

c	Write total number of nodes

	write(1,*)n*m+3

c	Write total number of wire segments

	write(1,*)n*m+2

c	Write total number of ports

	write(1,*)1
	write(1,*)

	pi=4.*atan(1.)
	dangle=2.*pi/m
	dz=hp/m

c	Helix is approximated by a broken line inscribed in a helix of a 
c	larger radius, so that the original helix is midway between the
c	inscribed and circumscribed helixes

	her=2.*hr/(1.+cos(.5*dangle))

c	write node coordinates

c	Helix base has two additional segments. The first segment originates
c	at the ground plane and runs along the helix axis. The feed is located
c	at the origin of this segment, and its length is 1/4 of the helix
c	pitch. The second segment is parallel to the ground plane, and it
c	connects the end of the first segment and the helix

	z0=0.25*hp+2.*wr
	write(1,*)0.,0.,0.
	write(1,*)0.,0.,z0

	do 1 i=0,n*m
	  x=her*cos(i*dangle)
	  y=her*sin(i*dangle)
	  z=dz*i+z0
	  write(1,*)x,y,z
1	continue

c	Write data for segments (starting and ending nodes,
c	wire radius and loadings)

	do 2 i=1,n*m+2
	  write(1,*)i,i+1,wr,' 0 0 64 0. 0. 0. 0. 0. 0. 0. 0. 0. 56.e6'
2	continue

c	Write data for port (port at the origin of segment 1, ideal voltage
c	generator, emf=1 volt, nominal impedance 50 ohm)

	write(1,*)'1 1 (1.,0.) 50.'

	close(1)

	end