******************************************************************************
*                                                                            *
*   PROGRAM: lpda                                                            *
*                                                                            *
*   PURPOSE: Create Awas geometry input data file for a LPDA                 *
*                                                                            *
******************************************************************************

	program lpda

c	Dipole arms are scaled in only in length
c	Feeder and dipole arm radii are not scaled

	character*76 title1,title2,title3

c	Read input data (dimensions are in mm)

	open(file='lpda.dat',unit=1,status='old')

	read(1,'(a76)')title1	! Title lines
	read(1,'(a76)')title2
	read(1,'(a76)')title3

	read(1,*)nd		! Number of dipoles

	read(1,*)hmin		! Length of the first (shortest) dipole arm
	hmin=hmin*0.001
	read(1,*)amin		! Radius of the dipole arms
	amin=amin*0.001

	read(1,*)dmin		! Pitch between the first and second dipoles
	dmin=dmin*0.001

	read(1,*)tau		! Ratio of dimensions of adjacent dipoles 
				! (tau<1)

	read(1,*)dline		! Distance between feeder conductors
	dline=dline*0.001
	read(1,*)aline		! Radius of feeder conductors
	aline=aline*0.001

	close(1)

c	Open file LPDA.GEO (the old copy will be deleted if it exists)

	open (file='lpda.geo',unit=1)

c	Write title lines

	write(1,'(a76)')title1
	write(1,'(a76)')title2
	write(1,'(a76)')title3

c	Write operating mode code (transmitting antenna, all ports)

	write(1,*)1

c	Write ground plane indicator (ground not present)

	write(1,*)0

c	Write total number of nodes

	write(1,*)4*nd+4

c	Write total number of wire segments

	write(1,*)4*nd+4

c	Write total number of ports

	write(1,*)1
	write(1,*)

c	Write node coordinates

	ratio=1./tau
	tga=(ratio-1.)*hmin/dmin
	x0=hmin/tga
	dlineh=0.5*dline

	write(1,*)x0-tau*dmin,0.,-dlineh
	write(1,*)x0-tau*dmin,0.,dlineh
	xtemp=x0
	htemp=hmin
	dtemp=dmin

	do i=1,nd
	  write(1,*)xtemp,0.,-dlineh
	  write(1,*)xtemp,0.,dlineh

	  write(1,*)xtemp,-htemp,-dlineh
	  write(1,*)xtemp,htemp,dlineh

	  xtemp=xtemp+dtemp
	  dtemp=dtemp*ratio
	  htemp=-htemp*ratio
	end do

	write(1,*)xtemp,0.,-dlineh
	write(1,*)xtemp,0.,dlineh

c	Write data for segments (starting and ending nodes, 
c	wire radius and data for loadings)

	write(1,*)1,2,aline,' 0 0 64 0 0 0 0 0 0 0 0 0 16.e6'
	write(1,*)1,3,aline,' 0 0 64 0 0 0 0 0 0 0 0 0 16.e6'
	write(1,*)2,4,aline,' 0 0 64 0 0 0 0 0 0 0 0 0 16.e6'

	k=3
	atemp=amin

	do i=1,nd
	  write(1,*)k,k+4,aline,' 0 0 64 0 0 0 0 0 0 0 0 0 16.e6'
	  write(1,*)k+1,k+5,aline,' 0 0 64 0 0 0 0 0 0 0 0 0 16.e6'
	  write(1,*)k,k+2,atemp,' 0 0 64 0 0 0 0 0 0 0 0 0 16.e6'
	  write(1,*)k+1,k+3,atemp,' 0 0 64 0 0 0 0 0 0 0 0 0 16.e6'
	  k=k+4
	end do

	write(1,*)k,k+1,aline,' 0 0 64 0 0 0 0 0 0 0 0 0 16.e6'

c	Write data for ports

	write(1,*)1,1,(1.,0.),50.

	close(1)

	end