******************************************************************************
*                                                                            *
*   PROGRAM: pcoil                                                           *
*                                                                            *
*   PURPOSE: Create Awas geometry input data file for a square               *
*            printed-circuit coil located above a ground plane               *
*            and treated as a two-port network                               *
*                                                                            *
******************************************************************************

	program PCOIL

c	The basic data are input from the keyboard,
c	and the data created by the program are written in the file PCOIL.GEO

c	ENTER DATA

c	enter number of turns (integer)

	write(*,100)
100	format(' Number of turns? ',$)
	read(*,*)n
	if(n.lt.1) n=1

c	enter number substrate thickness

	write(*,101)
101	format(' Substrate thickness (mm)? ',$)
	read(*,*)h
	h=h*0.001

c	enter shortest side length, pitch and wire radius

	write(*,102)
102	format(' Shortest side length (mm)? ',$)
	read(*,*)s
	s=s*0.001
	write(*,103)
103	format(' Pitch (mm)? ',$)
	read(*,*)p
	p=p*0.001
	write(*,104)
104	format(' Wire radius (mm)? ',$)
	read(*,*)r
	r=r*0.001

c	WRITE DATA

c	open file PCOIL.GEO (the old copy will be deleted if it exists)

	open (file='pcoil.geo',unit=1)

c	write three title lines (each line must contain EXACTLY 76 characters)

	write(1,200)
	write(1,200)
	write(1,200)
200	format('                                     ',
     1	'                                       ')

c	write operating mode code (transmitting antenna, one port at a time)

	write(1,*)-1

c	write ground plane indicator (ground plane present)

	write(1,*)1

c	write total number of nodes

	write(1,*)4*n+3

c	write total number of wire segments

	write(1,*)4*n+2

c	write total number of ports

	write(1,*)2
	write(1,*)

c	write node coordinates

	x=0.5*s
	y=-(x-0.25*p)

	write(1,*)x,y,0.
	write(1,*)x,y,h
	do 1 i=1,n
	  y=-y+0.5*p
	  write(1,*)x,y,h
	  x=-x-0.5*p
	  write(1,*)x,y,h
	  y=-y-0.5*p
	  write(1,*)x,y,h
	  x=-x+0.5*p
	  write(1,*)x,y,h
1	continue
	write(1,*)x,y,0.

c	write data for segments (starting and ending nodes, 
c	wire radius and data for loadings)

	do 2 i=1,4*n+1
	  write(1,*)i,i+1,r,' 0 0 64 0. 0. 0. 0. 0. 0. 0. 0. 0. 10.e6'
2	continue
	write(1,*)4*n+3,4*n+2,r,
     1	' 0 0 64 0. 0. 0. 0. 0. 0. 0. 0. 0. 10.e6'

c	write data for port (ports at segments 1 and 4*n+2, emf=1 volt,
c	feeder characteristic impedance 50 ohm)

	write(1,*)1,1,(1.,0.),50.
	write(1,*)4*n+2,1,(1.,0.),50.

	close(1)

	end