******************************************************************************
*                                                                            *
*   PROGRAM: spar                                                            *
*                                                                            *
*   PURPOSE: Convert Awas output WIRE.SPM to a format readable by other      *
*            programs                                                        *
*                                                                            *
******************************************************************************

	program spar

	real sr(99,99),si(99,99),smod(99,99),sphase(99,99)
	character*3 filexts

	pi=4.*atan(1.)
	rdcf=180./pi

c	read the header of WIRE.SPM

	open (file='wire.spm',unit=2,status='old')

	read(2,*)mode			! read operating mode
	read(2,*)fstart,fstop,nf	! read frequency data
	read(2,*)nn			! read number of nodes
	read(2,*)nb			! read number of segments
	read(2,*)np			! read number of ports
	do i=1,nn			! read data for nodes
	  read(2,*)x,y,z
	end do
	do i=1,nb			! read data for segments
	  read(2,*)j1,j2
	end do
	do i=1,np			! read data for ports
	  read(2,*)ip
	end do

c	construct the file name extension for the output s-parameter file
c	the name is WIRE

	if(np.lt.10) then
	  write(filexts,201)np
201	  format('s',i1,'p')
	else
	  write(filexts,202)np
202	  format('s',i2)
	end if

c	open the output s-parameter file

	open(file='wire.'//filexts,unit=3)

c	write the header (frequency in GHz, s-parameters, magnitude and angle, 
c	port nominal impedance 50 ohm)

	write(3,203)
203	format('# GHZ S MA R 50')

	write(3,204)
204	format('! S-parameter output from AWAS')

c	read s-parameters from WIRE.SPM and write them to the output file

	df=(fstop-fstart)/nf
	do k=0,nf
	  frequ=(fstart+k*df)*1.e-9
	  read(2,*,end=900)((sr(i,j),si(i,j),j=1,np),i=1,np)
	  do i=1,np
	    do j=1,np
	      smod(i,j)=sqrt(sr(i,j)*sr(i,j)+si(i,j)*si(i,j))
	      sphase(i,j)=atan2(si(i,j),sr(i,j))*rdcf
	    end do
	  end do

	  if(np.eq.1) then
	    write(3,211)frequ,smod(1,1),sphase(1,1)
	  else if(np.eq.2) then
	    write(3,211)
     1	    frequ,smod(1,1),sphase(1,1),smod(2,1),
     2	    sphase(2,1),smod(1,2),sphase(1,2),smod(2,2),
     3	    sphase(2,2)
211	    format(1p,9e12.4)
212	    format(12x,1p,8e12.4)
	  else if(np.eq.3) then
	    write(3,211)
     1	    frequ,(smod(1,j),sphase(1,j),j=1,np)
	    do i=2,np
	      write(3,212)(smod(i,j),sphase(i,j),j=1,np)
	    end do
	  else
	    write(3,211)
     1	    frequ,(smod(1,j),sphase(1,j),j=1,4)
	    if(np.gt.4) then
	      write(3,212)(smod(1,j),sphase(1,j),j=5,np)
	    end if
	    do i=2,np
	      write(3,212)(smod(i,j),sphase(i,j),j=1,np)
	    end do
	  end if
	end do

900	close(2)
	close(3)

	end